==> cxf-testutils-2.0.5.0-fuse-sources.jar: org/apache/type_test/xml/TestChoiceOfChoiceResponse.java <==

package org.apache.type_test.xml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types2.ChoiceOfChoice;


/**
 * <p>Java class for testChoiceOfChoiceResponse element declaration.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;element name="testChoiceOfChoiceResponse">
 *   &lt;complexType>
 *     &lt;complexContent>
 *       &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *         &lt;sequence>
 *           &lt;element name="return" type="{http://apache.org/type_test/types2}ChoiceOfChoice"/>
 *           &lt;element name="y" type="{http://apache.org/type_test/types2}ChoiceOfChoice"/>
 *           &lt;element name="z" type="{http://apache.org/type_test/types2}ChoiceOfChoice"/>
 *         &lt;/sequence>
 *       &lt;/restriction>
 *     &lt;/complexContent>
 *   &lt;/complexType>
 * &lt;/element>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "_return",
    "y",
    "z"
})
@XmlRootElement(name = "testChoiceOfChoiceResponse")
public class TestChoiceOfChoiceResponse {

    @XmlElement(name = "return", namespace = "http://apache.org/type_test/xml", required = true)
    protected ChoiceOfChoice _return;
    @XmlElement(namespace = "http://apache.org/type_test/xml", required = true)
    protected ChoiceOfChoice y;
    @XmlElement(namespace = "http://apache.org/type_test/xml", required = true)
    protected ChoiceOfChoice z;

    /**
     * Gets the value of the return property.
     * 
     * @return
     *     possible object is
     *     {@link ChoiceOfChoice }
     *     
     */
    public ChoiceOfChoice getReturn() {
        return _return;
    }

    /**
     * Sets the value of the return property.
     * 
     * @param value
     *     allowed object is
     *     {@link ChoiceOfChoice }
     *     
     */
    public void setReturn(ChoiceOfChoice value) {
        this._return = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link ChoiceOfChoice }
     *     
     */
    public ChoiceOfChoice getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link ChoiceOfChoice }
     *     
     */
    public void setY(ChoiceOfChoice value) {
        this.y = value;
    }

    /**
     * Gets the value of the z property.
     * 
     * @return
     *     possible object is
     *     {@link ChoiceOfChoice }
     *     
     */
    public ChoiceOfChoice getZ() {
        return z;
    }

    /**
     * Sets the value of the z property.
     * 
     * @param value
     *     allowed object is
     *     {@link ChoiceOfChoice }
     *     
     */
    public void setZ(ChoiceOfChoice value) {
        this.z = value;
    }

}

==> cxf-testutils-2.1.3.3-fuse-sources.jar: org/apache/type_test/xml/TestChoiceOfChoiceResponse.java <==

package org.apache.type_test.xml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types2.ChoiceOfChoice;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="return" type="{http://apache.org/type_test/types2}ChoiceOfChoice"/>
 *         &lt;element name="y" type="{http://apache.org/type_test/types2}ChoiceOfChoice"/>
 *         &lt;element name="z" type="{http://apache.org/type_test/types2}ChoiceOfChoice"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "_return",
    "y",
    "z"
})
@XmlRootElement(name = "testChoiceOfChoiceResponse")
public class TestChoiceOfChoiceResponse {

    @XmlElement(name = "return", required = true)
    protected ChoiceOfChoice _return;
    @XmlElement(required = true)
    protected ChoiceOfChoice y;
    @XmlElement(required = true)
    protected ChoiceOfChoice z;

    /**
     * Gets the value of the return property.
     * 
     * @return
     *     possible object is
     *     {@link ChoiceOfChoice }
     *     
     */
    public ChoiceOfChoice getReturn() {
        return _return;
    }

    /**
     * Sets the value of the return property.
     * 
     * @param value
     *     allowed object is
     *     {@link ChoiceOfChoice }
     *     
     */
    public void setReturn(ChoiceOfChoice value) {
        this._return = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link ChoiceOfChoice }
     *     
     */
    public ChoiceOfChoice getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link ChoiceOfChoice }
     *     
     */
    public void setY(ChoiceOfChoice value) {
        this.y = value;
    }

    /**
     * Gets the value of the z property.
     * 
     * @return
     *     possible object is
     *     {@link ChoiceOfChoice }
     *     
     */
    public ChoiceOfChoice getZ() {
        return z;
    }

    /**
     * Sets the value of the z property.
     * 
     * @param value
     *     allowed object is
     *     {@link ChoiceOfChoice }
     *     
     */
    public void setZ(ChoiceOfChoice value) {
        this.z = value;
    }

}
